.. all-saltext.elasticsearch.returners:

________________
Returner Modules
________________

.. currentmodule:: saltext.elasticsearch.returners

.. autosummary::
    :toctree:

    elasticsearch6_mod
    elasticsearch8_mod
    elasticsearch9_mod
